Package: hyperdraw
Version: 1.64.0
Depends: R (>= 2.9.0)
Imports: methods, grid, graph, hypergraph, Rgraphviz, stats4
SystemRequirements: graphviz
Title: Visualizing Hypergaphs
Author: Paul Murrell
Maintainer: Paul Murrell <p.murrell@auckland.ac.nz>
Description: Functions for visualizing hypergraphs.
License: GPL (>= 2)
Collate: AllClasses.R affine.R draw.R graphBPH.R grid.R hypergraph.R
        legacy.R node.R RagraphBPH.R
biocViews: Visualization, GraphAndNetwork
git_url: https://git.bioconductor.org/packages/hyperdraw
git_branch: RELEASE_3_23
git_last_commit: ad9ee55
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:28:39 UTC; biocbuild
Built: R 4.6.0; ; 2026-04-29 04:46:43 UTC; unix
